==> knative-model-6.3.1-sources.jar: io/fabric8/knative/eventing/v1/TriggerFluentImpl.java <==
package io.fabric8.knative.eventing.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerFluentImpl<A extends TriggerFluent<A>> extends BaseFluent<A> implements TriggerFluent<A>{
  public TriggerFluentImpl() {
  }
  public TriggerFluentImpl(Trigger instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TriggerSpecBuilder spec;
  private TriggerStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TriggerFluent.MetadataNested<A> withNewMetadata() {
    return new TriggerFluentImpl.MetadataNestedImpl();
  }
  public TriggerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TriggerFluentImpl.MetadataNestedImpl(item);
  }
  public TriggerFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TriggerFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TriggerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerFluent.SpecNested<A> withNewSpec() {
    return new TriggerFluentImpl.SpecNestedImpl();
  }
  public TriggerFluent.SpecNested<A> withNewSpecLike(TriggerSpec item) {
    return new TriggerFluentImpl.SpecNestedImpl(item);
  }
  public TriggerFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerSpecBuilder().build());
  }
  public TriggerFluent.SpecNested<A> editOrNewSpecLike(TriggerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TriggerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TriggerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TriggerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TriggerFluent.StatusNested<A> withNewStatus() {
    return new TriggerFluentImpl.StatusNestedImpl();
  }
  public TriggerFluent.StatusNested<A> withNewStatusLike(TriggerStatus item) {
    return new TriggerFluentImpl.StatusNestedImpl(item);
  }
  public TriggerFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TriggerFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerStatusBuilder().build());
  }
  public TriggerFluent.StatusNested<A> editOrNewStatusLike(TriggerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TriggerFluentImpl that = (TriggerFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerFluent.MetadataNested<N>> implements TriggerFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TriggerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TriggerSpecFluentImpl<TriggerFluent.SpecNested<N>> implements TriggerFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerSpec item) {
      this.builder = new TriggerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerSpecBuilder(this);
    }
    TriggerSpecBuilder builder;
    public N and() {
      return (N) TriggerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TriggerStatusFluentImpl<TriggerFluent.StatusNested<N>> implements TriggerFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TriggerStatus item) {
      this.builder = new TriggerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TriggerStatusBuilder(this);
    }
    TriggerStatusBuilder builder;
    public N and() {
      return (N) TriggerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/v1/TriggerFluentImpl.java <==
package io.fabric8.knative.eventing.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TriggerFluentImpl<A extends TriggerFluent<A>> extends BaseFluent<A> implements TriggerFluent<A>{
  public TriggerFluentImpl() {
  }
  public TriggerFluentImpl(Trigger instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private TriggerSpecBuilder spec;
  private TriggerStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public TriggerFluentImpl.MetadataNested<A> withNewMetadata() {
    return new TriggerFluentImpl.MetadataNestedImpl();
  }
  public TriggerFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new TriggerFluentImpl.MetadataNestedImpl(item);
  }
  public TriggerFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public TriggerFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public TriggerFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public TriggerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(TriggerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new TriggerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public TriggerFluentImpl.SpecNested<A> withNewSpec() {
    return new TriggerFluentImpl.SpecNestedImpl();
  }
  public TriggerFluentImpl.SpecNested<A> withNewSpecLike(TriggerSpec item) {
    return new TriggerFluentImpl.SpecNestedImpl(item);
  }
  public TriggerFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public TriggerFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new TriggerSpecBuilder().build());
  }
  public TriggerFluentImpl.SpecNested<A> editOrNewSpecLike(TriggerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public TriggerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public TriggerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(TriggerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new TriggerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public TriggerFluentImpl.StatusNested<A> withNewStatus() {
    return new TriggerFluentImpl.StatusNestedImpl();
  }
  public TriggerFluentImpl.StatusNested<A> withNewStatusLike(TriggerStatus item) {
    return new TriggerFluentImpl.StatusNestedImpl(item);
  }
  public TriggerFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public TriggerFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new TriggerStatusBuilder().build());
  }
  public TriggerFluentImpl.StatusNested<A> editOrNewStatusLike(TriggerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TriggerFluentImpl that = (TriggerFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<TriggerFluentImpl.MetadataNested<N>> implements TriggerFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) TriggerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends TriggerSpecFluentImpl<TriggerFluentImpl.SpecNested<N>> implements TriggerFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(TriggerSpec item) {
      this.builder = new TriggerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new TriggerSpecBuilder(this);
    }
    TriggerSpecBuilder builder;
    public N and() {
      return (N) TriggerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends TriggerStatusFluentImpl<TriggerFluentImpl.StatusNested<N>> implements TriggerFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(TriggerStatus item) {
      this.builder = new TriggerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new TriggerStatusBuilder(this);
    }
    TriggerStatusBuilder builder;
    public N and() {
      return (N) TriggerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
